@@ -1,27 +1,23 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "הערות",
     "Reading notes from filesystem has failed." : "קריאת הפתקים ממערכת הקבצים נכשלה.",
     "Error" : "שגיאה",
     "New note" : "פתק חדש",
-    "Notes" : "הערות",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
     "Please see Nextcloud server log for details." : "נא לעיין ביומן השרת של Nextcloud לפרטים נוספים.",
     "Deleted {title}" : "{title} נמחק",
-    "Deleted {number} notes" : "נמחקו {number} פתקים",
     "Undo Delete" : "ביטול מחיקה",
     "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
     "Settings" : "הגדרות",
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
     "path to notes" : "נתיב לפתקיות",
     "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
+    "No notes yet" : "אין פתקים עדיין",
     "All notes" : "כל הפתקים",
     "Categories" : "קטגוריות",
-    "No search result for “{search}” in {category}" : "אין תוצאות לחיפוש אחר „{search}” ב{category}",
-    "No search result for “{search}”" : "אין תוצאות לחיפוש אחר „{search}”",
     "Loading …" : "בטעינה",
-    "Search result for “{search}” in {category}" : "תוצאות לחיפוש אחר „{search}” ב{category}",
-    "Search result for “{search}”" : "תוצאות לחיפוש אחר „{search}”",
     "Today" : "היום",
     "Yesterday" : "אתמול",
     "This week" : "השבוע",
