@@ -1,27 +1,23 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "ノート",
     "Reading notes from filesystem has failed." : "ファイルシステムからノートを読み込めませんでした。",
     "Error" : "エラー",
     "New note" : "新しいノート",
-    "Notes" : "ノート",
     "Distraction-free notes and writing" : "集中モードのノートと執筆",
     "Please see Nextcloud server log for details." : "詳細はNextcloudサーバーログをご確認下さい。",
     "Deleted {title}" : "{title}を削除しました",
-    "Deleted {number} notes" : "{number}のメモを削除しました",
     "Undo Delete" : "削除取り消し",
     "There are unsaved notes. Leaving the page will discard all changes!" : "保存されていないノートがあります。このページから移動するとすべての変更は破棄されます。",
     "Settings" : "設定",
     "Folder to store your notes" : "ノートを保存するフォルダー",
     "path to notes" : "ノートへのパス",
     "File extension for new notes" : "新しいノートのファイル拡張子",
+    "No notes yet" : "まだノートはありません",
     "All notes" : "すべてのノート",
     "Categories" : "カテゴリ",
-    "No search result for “{search}” in {category}" : "{category}の{search}の検索結果はありません",
-    "No search result for “{search}”" : "{search}の検索結果はありません。",
     "Loading …" : "読み込み中...",
-    "Search result for “{search}” in {category}" : "{category}の{search}の検索結果",
-    "Search result for “{search}”" : "\"{search}\"の検索結果",
     "Today" : "今日",
     "Yesterday" : "昨日",
     "This week" : "今週",
