@@ -49,8 +49,12 @@ class Note {
 			throw new \Exception('Can\'t read file content for '.$this->file->getPath());
 		}
 		if (!mb_check_encoding($content, 'UTF-8')) {
+			$this->util->logger->warning(
+				'File encoding for '.$this->file->getPath().' is not UTF-8. This may cause problems.'
+			);
 			$content = mb_convert_encoding($content, 'UTF-8');
 		}
+		$content = str_replace([ pack('H*', 'FEFF'), pack('H*', 'FFEF'), pack('H*', 'EFBBBF') ], '', $content);
 		return $content;
 	}
 
@@ -58,14 +62,14 @@ class Note {
 		$excerpt = trim($this->noteUtil->stripMarkdown($this->getContent()));
 		$title = $this->getTitle();
 		if (!empty($title)) {
-			$length = strlen($title);
+			$length = mb_strlen($title, "utf-8");
 			if (strncasecmp($excerpt, $title, $length) === 0) {
-				$excerpt = substr($excerpt, $length);
+				$excerpt = mb_substr($excerpt, $length, null, "utf-8");
 			}
 		}
 		$excerpt = trim($excerpt);
-		if (strlen($excerpt) > $maxlen) {
-			$excerpt = substr($excerpt, 0, $maxlen) . '…';
+		if (mb_strlen($excerpt, "utf-8") > $maxlen) {
+			$excerpt = mb_substr($excerpt, 0, $maxlen, "utf-8") . '…';
 		}
 		return str_replace("\n", "\u{2003}", $excerpt);
 	}
