@@ -1,4 +1,4 @@
 <?php
-script('notes', 'notes');
+
+script('notes', 'notes-main');
 style('notes', 'notes');
-?>
